summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_inline.h
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/rendering/render_inline.h')
-rw-r--r--khtml/rendering/render_inline.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/khtml/rendering/render_inline.h b/khtml/rendering/render_inline.h
index 5f4bf7b29..3bb290392 100644
--- a/khtml/rendering/render_inline.h
+++ b/khtml/rendering/render_inline.h
@@ -54,7 +54,7 @@ public:
virtual void setStyle(RenderStyle* _style);
virtual void attach();
- virtual void layout() {} // Do nothing for layout()
+ virtual void tqlayout() {} // Do nothing for tqlayout()
virtual void paint(PaintInfo&, int tx, int ty);